
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

.. automodule:: adafruit_midi
   :members:

.. automodule:: adafruit_midi.channel_pressure
      :members:

.. automodule:: adafruit_midi.control_change
      :members:

.. automodule:: adafruit_midi.control_change_values
      :members:

.. automodule:: adafruit_midi.midi_continue
      :members:

.. automodule:: adafruit_midi.midi_message
      :members:

.. automodule:: adafruit_midi.mtc_quarter_frame
      :members:

.. automodule:: adafruit_midi.note_off
      :members:

.. automodule:: adafruit_midi.note_on
      :members:

.. automodule:: adafruit_midi.pitch_bend
      :members:

.. automodule:: adafruit_midi.polyphonic_key_pressure
      :members:

.. automodule:: adafruit_midi.program_change
      :members:

.. automodule:: adafruit_midi.start
      :members:

.. automodule:: adafruit_midi.stop
      :members:

.. automodule:: adafruit_midi.system_exclusive
      :members:

.. automodule:: adafruit_midi.timing_clock
      :members:
